thermferm/thermferm.h

changeset 306
97602274eb58
parent 293
881b1ae75468
child 310
53774295e14a
--- a/thermferm/thermferm.h	Wed Jan 14 13:20:16 2015 +0100
+++ b/thermferm/thermferm.h	Sat Feb 07 23:12:55 2015 +0100
@@ -96,9 +96,8 @@
  * Fermenter units. These units are connected via the 1-wire bus.
  * Each unit can have:
  *  a DS18B20 sensor to measure the air temperature inside the unit.
  *  a DS18B20 sensor to measure the beer temperature.
  *  a DS2413 to turn the cooler and heater on or off.
  *  a DS2413 to switch the fan and sense the door.
  */
 typedef struct _units_list {
     struct _units_list	*next;
@@ -127,8 +126,15 @@
     int			fan_delay;		/* Fan delay time /15 sec	*/
     int			fan_wait;		/* Fan wait counter		*/
     int			fan_usage;		/* Fan usage in seconds		*/
+    char		*light_address;		/* Lights relay			*/
+    int			light_state;		/* Lights state 0..100		*/
+    int			light_delay;		/* Lights delay time /15 sec	*/
+    int			light_wait;		/* Lights wait counter		*/
+    int			light_usage;		/* Lights usage in seconds	*/
     char		*door_address;		/* Door input address		*/
-    int			door_state;		/* Door and light status	*/
+    int			door_state;		/* Door status			*/
+    char		*psu_address;		/* Power Supply input address	*/
+    int			psu_state;		/* Power Supply status		*/
     int			mode;			/* Unit mode			*/
     float		beer_set;		/* Beer temperature setting	*/
     float		fridge_set;		/* Fridge temperature setting	*/
@@ -96,9 +96,8 @@
  * Each unit can have:
  *  a DS18B20 sensor to measure the air temperature inside the unit.
- *  a DS18B20 sensor to measure the beer temperature.
- *  a DS2413 to turn the cooler and heater on or off.
- *  a DS2413 to switch the fan and sense the door.
+ *  a DS18B20 sensor(s) to measure the beer temperature.
+ *  a DS2408 to turn the cooler, heater and fans on or off. Sense door and PSU state.
  */
 typedef struct _units_list {

mercurial